firstPageErrorIndicator property
Widget to display when an error occurs fetching the first page.
Implementation
final Widget? firstPageErrorIndicator;
Widget to display when an error occurs fetching the first page.
final Widget? firstPageErrorIndicator;