newPageErrorIndicator property
Widget to display when an error occurs fetching a subsequent page.
Implementation
final Widget? newPageErrorIndicator;
Widget to display when an error occurs fetching a subsequent page.
final Widget? newPageErrorIndicator;