newPageProgressIndicator property
Widget to display at the bottom when loading subsequent pages.
Implementation
final Widget? newPageProgressIndicator;
Widget to display at the bottom when loading subsequent pages.
final Widget? newPageProgressIndicator;