build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
return ListenableBuilder(
listenable: controller,
builder: (context, _) {
final items = controller.items;
final isLoading = controller.isLoading;
final hasMore = controller.hasMore;
final error = controller.error;
if (items.isEmpty && isLoading) {
return firstPageProgressIndicator ??
const Center(
child: Padding(
padding: EdgeInsets.all(24.0),
child: Column(
children: [
SuperSkeleton(height: 150, margin: EdgeInsets.only(bottom: 12)),
SuperSkeleton(height: 100, margin: EdgeInsets.only(bottom: 12)),
SuperSkeleton(height: 200),
],
),
),
);
}
if (items.isEmpty && !isLoading && !hasMore) {
return noItemsFoundIndicator ??
const Center(child: Text('No items found'));
}
// Distribute items into columns (Round-robin for simple in-built version)
final List<List<T>> columns = List.generate(crossAxisCount, (_) => []);
for (int i = 0; i < items.length; i++) {
columns[i % crossAxisCount].add(items[i]);
}
final content = SingleChildScrollView(
controller: scrollController,
padding: padding,
physics: physics,
reverse: reverse,
child: Column(
children: [
Row(
crossAxisAlignment: CrossAxisAlignment.start,
children: List.generate(crossAxisCount, (colIndex) {
return Expanded(
child: Padding(
padding: EdgeInsets.only(
left: colIndex == 0 ? 0 : crossAxisSpacing / 2,
right: colIndex == crossAxisCount - 1 ? 0 : crossAxisSpacing / 2,
),
child: Column(
children: [
for (int i = 0; i < columns[colIndex].length; i++)
Padding(
padding: EdgeInsets.only(bottom: mainAxisSpacing),
child: itemBuilder(context, columns[colIndex][i],
items.indexOf(columns[colIndex][i])),
),
],
),
),
);
}),
),
// Footer items
if (isLoading)
newPageProgressIndicator ??
const Padding(
padding: EdgeInsets.symmetric(vertical: 16.0, horizontal: 16.0),
child: Center(
child: SuperSkeleton(
height: 20,
width: 200,
),
),
),
if (error != null)
newPageErrorIndicator ??
Center(
child: Padding(
padding: const EdgeInsets.symmetric(vertical: 16.0),
child: Column(
children: [
const Text('Error loading more items'),
TextButton(
onPressed: () => controller.loadMore(),
child: const Text('Retry'),
),
],
),
),
),
if (!hasMore && items.isNotEmpty)
noMoreItemsIndicator ?? const SizedBox.shrink(),
],
),
);
return SuperScroll(
controller: controller,
scrollController: scrollController,
showFooter: false,
child: content,
);
},
);
}