firstPageProgressIndicator property
Widget to display when the first page is loading. If null, a default SuperSkeleton list is used.
Implementation
final Widget? firstPageProgressIndicator;
Widget to display when the first page is loading. If null, a default SuperSkeleton list is used.
final Widget? firstPageProgressIndicator;