newPageProgressIndicator property
Widget to display at the bottom when loading subsequent pages. If null, a default SuperSkeleton is used.
Implementation
final Widget? newPageProgressIndicator;
Widget to display at the bottom when loading subsequent pages. If null, a default SuperSkeleton is used.
final Widget? newPageProgressIndicator;