scrollController property
An optional ScrollController to monitor the scroll position. If not provided, an internal one will be created.
Implementation
final ScrollController? scrollController;
An optional ScrollController to monitor the scroll position. If not provided, an internal one will be created.
final ScrollController? scrollController;