showFooter property
Whether to show the default footer (indicators) managed by SuperScroll. Set to false if the child manages its own indicators (e.g., using SuperSliverList).
Implementation
final bool showFooter;
Whether to show the default footer (indicators) managed by SuperScroll. Set to false if the child manages its own indicators (e.g., using SuperSliverList).
final bool showFooter;