error property
Object?
get
error
The error encountered during the last fetch, if any.
Implementation
Object? get error => _error;
The error encountered during the last fetch, if any.
Object? get error => _error;