onFetch property
The callback that fetches new items for a given page.
Implementation
final Future<SuperScrollResult<T>> Function(int page) onFetch;
The callback that fetches new items for a given page.
final Future<SuperScrollResult<T>> Function(int page) onFetch;