SuperScrollResult<T> class

A result object returned from the onFetch callback.

Constructors

SuperScrollResult({required List<T> items, required bool hasMore})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMore bool
Whether there are more items to be fetched.
final
items List<T>
The list of items fetched for the current page.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited