SuperGridView<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SuperGridView
Constructors
-
SuperGridView({Key? key, required SuperScrollController<
T> controller, required SuperItemBuilder<T> itemBuilder, required SliverGridDelegate gridDelegate, EdgeInsetsGeometry? padding, ScrollPhysics? physics, bool shrinkWrap = false, bool reverse = false, VoidCallback? onRefresh, ScrollController? scrollController, Widget? newPageProgressIndicator, Widget? firstPageProgressIndicator, Widget? firstPageErrorIndicator, Widget? newPageErrorIndicator, Widget? noItemsFoundIndicator, Widget? noMoreItemsIndicator}) -
const
-
SuperGridView.count({Key? key, required SuperScrollController<
T> controller, required SuperItemBuilder<T> itemBuilder, required int crossAxisCount, double mainAxisSpacing = 0.0, double crossAxisSpacing = 0.0, double childAspectRatio = 1.0, EdgeInsetsGeometry? padding, ScrollPhysics? physics, bool shrinkWrap = false, bool reverse = false, VoidCallback? onRefresh, ScrollController? scrollController, Widget? newPageProgressIndicator, Widget? firstPageProgressIndicator, Widget? firstPageErrorIndicator, Widget? newPageErrorIndicator, Widget? noItemsFoundIndicator, Widget? noMoreItemsIndicator}) -
SuperGridView.extent({Key? key, required SuperScrollController<
T> controller, required SuperItemBuilder<T> itemBuilder, required double maxCrossAxisExtent, double mainAxisSpacing = 0.0, double crossAxisSpacing = 0.0, double childAspectRatio = 1.0, EdgeInsetsGeometry? padding, ScrollPhysics? physics, bool shrinkWrap = false, bool reverse = false, VoidCallback? onRefresh, ScrollController? scrollController, Widget? newPageProgressIndicator, Widget? firstPageProgressIndicator, Widget? firstPageErrorIndicator, Widget? newPageErrorIndicator, Widget? noItemsFoundIndicator, Widget? noMoreItemsIndicator})
Properties
-
controller
→ SuperScrollController<
T> -
final
- firstPageErrorIndicator → Widget?
-
Widget to display when an error occurs fetching the first page.
final
- firstPageProgressIndicator → Widget?
-
Widget to display when the first page is loading.
final
- gridDelegate → SliverGridDelegate
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
itemBuilder
→ SuperItemBuilder<
T> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- newPageErrorIndicator → Widget?
-
Widget to display when an error occurs fetching a subsequent page.
final
- newPageProgressIndicator → Widget?
-
Widget to display at the bottom when loading subsequent pages.
final
- noItemsFoundIndicator → Widget?
-
Widget to display when no items were found on the first page.
final
- noMoreItemsIndicator → Widget?
-
Widget to display when there are no more items to load.
final
- onRefresh → VoidCallback?
-
final
- padding → EdgeInsetsGeometry?
-
final
- physics → ScrollPhysics?
-
final
- reverse → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
final
- shrinkWrap → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SuperGridView< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited